@@ -7,15 +7,16 @@ OC.L10N.register(
     "New" : "Novo",
     "New folder" : "Nova fascikla",
     "Search" : "Search",
+    "_%n folder_::_%n folders_" : ["direktorij","direktoriji","direktoriji"],
     "Rename folder" : "Preimenuj fasciklu",
     "Cancel" : "Otkaži",
     "Shared with you" : "Shared with you",
     "Files" : "Datoteke",
     "Delete" : "Obriši",
-    "Settings" : "Podešavanje",
     "Title" : "Naslov",
     "Link" : "Veza",
     "Notes" : "Notes",
+    "Open file" : "Otvori Datoteku",
     "Owner" : "Vlasnik",
     "Sharing" : "Dijeljenje",
     "Share link" : "Podijelite vezu",
