@@ -196,6 +196,7 @@ OC.L10N.register(
     "Notes" : "筆記",
     "Notes for this bookmark …" : "此書籤的註記……",
     "Archived file" : "已封存的檔案",
+    "Open file" : "開啟檔案",
     "Download file" : "下載檔案",
     "Open file location" : "開啟檔案位置",
     "Link copied" : "連結已複製",
@@ -248,6 +249,7 @@ OC.L10N.register(
     "What" : "什麼",
     "Failed to count unavailable bookmarks" : "計算不可用的書籤失敗",
     "Failed to count archived bookmarks" : "計算已封存的書籤失敗",
+    "Failed to count deleted bookmarks" : "計算已刪除的書籤失敗",
     "Failed to count duplicated bookmarks" : "重複書籤計數失敗",
     "Failed to count bookmarks" : "計算書籤數量失敗",
     "Failed to load bookmark" : "載入書籤失敗",
