@@ -90,6 +90,7 @@ export const actions = {
 	LOAD_SHARED_FOLDERS: 'LOAD_SHARED_FOLDERS',
 
 	EMPTY_TRASHBIN: 'EMPTY_TRASHBIN',
+	COUNT_DELETED: 'COUNT_DELETED',
 }
 
 export default {
@@ -165,6 +166,38 @@ export default {
 			throw err
 		}
 	},
+	async [actions.COUNT_DELETED]({ commit, dispatch, state }) {
+		if (state.archivedCount === null) {
+			try {
+				const count = loadState('bookmarks', 'deletedCount')
+				return commit(mutations.SET_DELETED_COUNT, count)
+			} catch (e) {
+				console.warn(
+					'Could not load initial deleted bookmarks count state, continuing with HTTP request',
+				)
+			}
+		}
+		try {
+			const response = await axios.get(url(state, '/bookmark/deletedCount'))
+			const {
+				data: { item: count, data, status },
+			} = response
+			if (status !== 'success') {
+				throw new Error(data)
+			}
+			commit(mutations.SET_DELETED_COUNT, count)
+		} catch (err) {
+			console.error(err)
+			commit(
+				mutations.SET_ERROR,
+				AppGlobal.methods.t(
+					'bookmarks',
+					'Failed to count deleted bookmarks',
+				),
+			)
+			throw err
+		}
+	},
 	async [actions.COUNT_DUPLICATED]({ commit, dispatch, state }) {
 		if (state.duplicatedCount === null) {
 			try {
@@ -595,9 +628,12 @@ export default {
 						: response.data.data,
 				)
 			}
-			await dispatch(actions.COUNT_BOOKMARKS, -1)
-			await dispatch(actions.LOAD_FOLDER_CHILDREN_ORDER, -1)
-			await dispatch(actions.RELOAD_VIEW)
+			await Promise.all([
+				dispatch(actions.COUNT_BOOKMARKS, -1),
+			    dispatch(actions.LOAD_FOLDER_CHILDREN_ORDER, -1),
+			    dispatch(actions.RELOAD_VIEW),
+			    dispatch(actions.LOAD_FOLDERS, true),
+			])
 			commit(mutations.FETCH_END, 'importBookmarks')
 			return commit(
 				mutations.SET_NOTIFICATION,
@@ -917,7 +953,7 @@ export default {
 			if (!avoidReload) {
 				await dispatch(
 					actions.LOAD_FOLDER_CHILDREN_ORDER,
-					parentFolderId,
+					parentFolderItem ? parentFolderId : '-1',
 				)
 				await dispatch(actions.LOAD_FOLDERS)
 				await dispatch(actions.LOAD_DELETED_FOLDERS)
@@ -1201,6 +1237,7 @@ export default {
 		dispatch(actions.LOAD_TAGS)
 		dispatch(actions.COUNT_BOOKMARKS, -1)
 		dispatch(actions.COUNT_UNAVAILABLE)
+		dispatch(actions.COUNT_DELETED)
 		dispatch(actions.COUNT_ARCHIVED)
 	},
 
